@@ -15,62 +15,72 @@
 # limitations under the License.
 #
 
-from ai.h2o.sparkling import Initializer
-from ai.h2o.sparkling.ml.Utils import Utils
-from ai.h2o.sparkling.ml.algos.H2OSupervisedAlgoBase import H2OSupervisedAlgoBase
-from ai.h2o.sparkling.ml.params import H2OAutoMLParams
+from warnings import warn
 from pyspark import keyword_only
-from pyspark.sql import SparkSession
-from pyspark.sql.dataframe import DataFrame
+from ai.h2o.sparkling.Initializer import Initializer
+from ai.h2o.sparkling.ml.Utils import Utils
+from ai.h2o.sparkling.ml.algos.H2OSupervisedAlgorithmWithFoldColumn import H2OSupervisedAlgorithmWithFoldColumn
+from ai.h2o.sparkling.ml.params.H2OAutoMLParams import H2OAutoMLParams
+from ai.h2o.sparkling.ml.algos.H2OAutoMLExtras import H2OAutoMLExtras
 
 
-class H2OAutoML(H2OAutoMLParams, H2OSupervisedAlgoBase):
+class H2OAutoML(H2OAutoMLParams, H2OSupervisedAlgorithmWithFoldColumn, H2OAutoMLExtras):
 
     @keyword_only
     def __init__(self,
-                 ignoredCols=[],
-                 includeAlgos=["GLM", "DRF", "GBM", "DeepLearning", "StackedEnsemble", "XGBoost"],
-                 excludeAlgos=[],
+                 ignoredCols=None,
+                 leaderboardDataFrame=None,
+                 blendingDataFrame=None,
+                 columnsToCategorical=[],
+                 keepBinaryModels=False,
+                 withContributions=False,
+                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
+                 withLeafNodeAssignments=False,
+                 convertInvalidNumbersToNa=False,
+                 detailedPredictionCol="detailed_prediction",
+                 validationDataFrame=None,
+                 featuresCols=[],
+                 predictionCol="prediction",
+                 convertUnknownCategoricalLevelsToNa=False,
+                 splitRatio=1.0,
+                 monotoneConstraints={},
+                 withStageResults=False,
                  projectName=None,
-                 maxRuntimeSecs=0.0,
-                 stoppingRounds=3,
-                 stoppingTolerance=0.001,
-                 stoppingMetric="AUTO",
-                 sortMetric="AUTO",
+                 nfolds=-1,
                  balanceClasses=False,
                  classSamplingFactors=None,
                  maxAfterBalanceSize=5.0,
                  keepCrossValidationPredictions=False,
                  keepCrossValidationModels=False,
-                 maxModels=0,
+                 keepCrossValidationFoldAssignment=False,
+                 exportCheckpointsDir=None,
+                 distribution="AUTO",
+                 tweediePower=1.5,
+                 quantileAlpha=0.5,
+                 huberAlpha=0.9,
+                 customDistributionFunc=None,
                  labelCol="label",
                  foldCol=None,
                  weightCol=None,
-                 offsetCol=None,
-                 splitRatio=1.0,
+                 sortMetric="AUTO",
                  seed=-1,
-                 nfolds=5,
-                 allStringColumnsToCategorical=True,
-                 columnsToCategorical=[],
-                 predictionCol="prediction",
-                 detailedPredictionCol="detailed_prediction",
-                 withDetailedPredictionCol=False,
-                 featuresCols=[],
-                 convertUnknownCategoricalLevelsToNa=False,
-                 convertInvalidNumbersToNa=False,
-                 namedMojoOutputColumns=True,
-                 monotoneConstraints={},
-                 withContributions=False,
-                 withLeafNodeAssignments=False):
+                 maxModels=0,
+                 maxRuntimeSecs=0.0,
+                 maxRuntimeSecsPerModel=0.0,
+                 stoppingRounds=3,
+                 stoppingMetric="AUTO",
+                 stoppingTolerance=-1.0,
+                 excludeAlgos=None,
+                 includeAlgos=["GLM", "DRF", "GBM", "DeepLearning", "StackedEnsemble", "XGBoost"],
+                 exploitationRatio=-1.0):
         Initializer.load_sparkling_jar()
         super(H2OAutoML, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.H2OAutoML", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
-        self._set(**kwargs)
+        kwargs = self._updateInitKwargs(kwargs)
 
-    def getLeaderboard(self, *extraColumns):
-        if len(extraColumns) == 1 and isinstance(extraColumns[0], list):
-            extraColumns = extraColumns[0]
-        leaderboard_java = self._java_obj.getLeaderboard(extraColumns)
-        return DataFrame(leaderboard_java, SparkSession.builder.getOrCreate()._wrapped)
+        if 'interactionPairs' in kwargs:
+            warn("Interaction pairs are not supported!")
+        self._set(**kwargs)
+        self._transfer_params_to_java()
