@@ -39,7 +39,6 @@ class H2OGLM(H2OGLMParams, H2OSupervisedAlgorithmWithFoldColumn, FamilyBasedH2OT
                  withContributions=False,
                  dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
-                 namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
                  detailedPredictionCol="detailed_prediction",
                  validationDataFrame=None,
@@ -65,6 +64,7 @@ class H2OGLM(H2OGLMParams, H2OSupervisedAlgorithmWithFoldColumn, FamilyBasedH2OT
                  standardize=True,
                  coldStart=False,
                  missingValuesHandling="MeanImputation",
+                 influence=None,
                  nonNegative=False,
                  maxIterations=-1,
                  betaEpsilon=1.0E-4,
