@@ -17,25 +17,25 @@
 
 from warnings import warn
 from pyspark import keyword_only
-from ai.h2o.sparkling import Initializer
+from ai.h2o.sparkling.Initializer import Initializer
 from ai.h2o.sparkling.ml.Utils import Utils
 from ai.h2o.sparkling.ml.algos.H2OUnsupervisedAlgorithm import H2OUnsupervisedAlgorithm
 from ai.h2o.sparkling.ml.models.H2OKMeansMOJOModel import H2OKMeansMOJOModel
 from ai.h2o.sparkling.ml.params.H2OKMeansParams import H2OKMeansParams
-from ai.h2o.sparkling.ml.params.H2OCommonParams import H2OCommonParams
 from ai.h2o.sparkling.ml.algos.H2OKMeansExtras import H2OKMeansExtras
 
 
-class H2OKMeans(H2OKMeansParams, H2OCommonParams, H2OUnsupervisedAlgorithm, H2OKMeansExtras):
+class H2OKMeans(H2OKMeansParams, H2OUnsupervisedAlgorithm, H2OKMeansExtras):
 
     @keyword_only
     def __init__(self,
                  userPoints=None,
                  ignoredCols=None,
                  columnsToCategorical=[],
+                 keepBinaryModels=False,
                  withContributions=False,
+                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
-                 namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
                  detailedPredictionCol="detailed_prediction",
                  validationDataFrame=None,
@@ -44,7 +44,6 @@ class H2OKMeans(H2OKMeansParams, H2OCommonParams, H2OUnsupervisedAlgorithm, H2OK
                  convertUnknownCategoricalLevelsToNa=False,
                  splitRatio=1.0,
                  withStageResults=False,
-                 withDetailedPredictionCol=True,
                  maxIterations=10,
                  standardize=True,
                  seed=-1,
@@ -63,17 +62,14 @@ class H2OKMeans(H2OKMeansParams, H2OCommonParams, H2OUnsupervisedAlgorithm, H2OK
                  ignoreConstCols=True,
                  scoreEachIteration=False,
                  maxRuntimeSecs=0.0,
-                 exportCheckpointsDir=None,
-                 **kwargs):
+                 exportCheckpointsDir=None):
         Initializer.load_sparkling_jar()
         super(H2OKMeans, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.H2OKMeans", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
         kwargs = self._updateInitKwargs(kwargs)
-        if 'weightCol' in kwargs:
-            del kwargs['weightCol']
-            warn("The parameter 'weightCol' is deprecated and will be removed in the version 3.34.")
+
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
         self._set(**kwargs)
