@@ -34,7 +34,6 @@ class H2OXGBoostRegressor(H2OXGBoost):
                  withContributions=False,
                  dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
-                 namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
                  detailedPredictionCol="detailed_prediction",
                  validationDataFrame=None,
@@ -66,6 +65,7 @@ class H2OXGBoostRegressor(H2OXGBoost):
                  buildTreeOneNode=False,
                  saveMatrixDirectory=None,
                  calibrateModel=False,
+                 calibrationMethod="AUTO",
                  maxBins=256,
                  maxLeaves=0,
                  treeMethod="auto",
@@ -84,11 +84,14 @@ class H2OXGBoostRegressor(H2OXGBoost):
                  gpuId=None,
                  interactionConstraints=None,
                  scalePosWeight=1.0,
+                 evalMetric=None,
+                 scoreEvalMetricOnly=False,
                  modelId=None,
                  nfolds=0,
                  keepCrossValidationModels=True,
                  keepCrossValidationPredictions=False,
                  keepCrossValidationFoldAssignment=False,
+                 parallelizeCrossValidation=True,
                  distribution="AUTO",
                  tweediePower=1.5,
                  labelCol="label",
