@@ -17,14 +17,15 @@
 
 from ai.h2o.sparkling.ml.params.H2OMOJOModelParams import H2OSupervisedMOJOModelParams
 from pyspark.ml.util import _jvm
+from py4j.java_gateway import JavaObject
 from ai.h2o.sparkling.Initializer import Initializer
 from ai.h2o.sparkling.ml.models.H2OMOJOSettings import H2OMOJOSettings
 from ai.h2o.sparkling.ml.params.H2OTypeConverters import H2OTypeConverters
+from ai.h2o.sparkling.H2ODataFrameConverters import H2ODataFrameConverters
 from ai.h2o.sparkling.ml.params.HasIgnoredColsOnMOJO import HasIgnoredColsOnMOJO
-from ai.h2o.sparkling.ml.params.HasDeprecatedVariableImportancesOnMOJO import HasDeprecatedVariableImportancesOnMOJO
 
 
-class H2ODeepLearningMOJOModel(H2OSupervisedMOJOModelParams, HasIgnoredColsOnMOJO, HasDeprecatedVariableImportancesOnMOJO):
+class H2ODeepLearningMOJOModel(H2OSupervisedMOJOModelParams, HasIgnoredColsOnMOJO):
 
     @staticmethod
     def createFromMojo(pathToMojo, settings=H2OMOJOSettings.default()):
@@ -33,6 +34,17 @@ class H2ODeepLearningMOJOModel(H2OSupervisedMOJOModelParams, HasIgnoredColsOnMOJ
         javaModel = _jvm().ai.h2o.sparkling.ml.models.H2ODeepLearningMOJOModel.createFromMojo(pathToMojo, settings.toJavaObject())
         return H2ODeepLearningMOJOModel(javaModel)
 
+
+    def getCrossValidationModels(self):
+        cvModels = self._java_obj.getCrossValidationModelsAsArray()
+        if cvModels is None:
+            return None
+        elif isinstance(cvModels, JavaObject):
+            return [H2ODeepLearningMOJOModel(v) for v in cvModels]
+        else:
+            raise TypeError("Invalid type.")
+
+
     def getBalanceClasses(self):
         value = self._java_obj.getBalanceClasses()
         return value
@@ -213,11 +225,6 @@ class H2ODeepLearningMOJOModel(H2OSupervisedMOJOModelParams, HasIgnoredColsOnMOJ
         return value
 
 
-    def getAutoencoder(self):
-        value = self._java_obj.getAutoencoder()
-        return value
-
-
     def getUseAllFactorLevels(self):
         value = self._java_obj.getUseAllFactorLevels()
         return value
@@ -421,3 +428,6 @@ class H2ODeepLearningMOJOModel(H2OSupervisedMOJOModelParams, HasIgnoredColsOnMOJ
     def getAucType(self):
         value = self._java_obj.getAucType()
         return value
+
+    # Outputs
+
