@@ -1,3 +1,4 @@
+import numpy as np
 from collections import defaultdict
 from itertools import product
 
@@ -66,7 +67,7 @@ class Fairness:
 
         return {n: _get_tracked_frame(f["key"]["name"]) for n, f in zip(res.map_keys["string"], res.frames)}
 
-    def fair_pd_plot(self, frame, column, protected_columns, figsize=(16, 9), autoscale=True, save_plot_path=None):
+    def fair_pd_plot(self, frame, column, protected_columns, figsize=(16, 9), autoscale=True):
         """
         Partial dependence plot per protected group.
 
@@ -77,7 +78,6 @@ class Fairness:
                                       such as race, gender, age etc.
         :param figsize: Tuple with figure size; passed directly to matplotlib.
         :param autoscale: If ``True``, try to guess when to use log transformation on X axis.
-        :param save_plot_path: A path to save the plot via using matplotlib function savefig.
         :return: Matplotlib Figure object
 
         :examples:
@@ -102,10 +102,6 @@ class Fairness:
         >>> gbm.fair_pd_plot(test, "AGE", protected_columns)
         """
         import h2o
-        from h2o.utils.shared_utils import can_use_numpy
-        if not can_use_numpy():
-            raise ImportError("numpy is required for fair_pd_plot.")
-        import numpy as np
         from h2o.explanation._explain import no_progress_block
         from h2o.plot import get_matplotlib_pyplot
         from h2o.utils.typechecks import assert_is_type, is_type
@@ -156,11 +152,9 @@ class Fairness:
         plt.ylabel("Response")
         plt.legend()
         plt.grid()
-        if save_plot_path is not None:
-            plt.savefig(fname=save_plot_path)
         return plt.gcf()
 
-    def fair_roc_plot(self, frame, protected_columns, reference, favorable_class, figsize=(16, 9), save_plot_path=None):
+    def fair_roc_plot(self, frame, protected_columns, reference, favorable_class, figsize=(16, 9)):
         """
         Plot ROC curve per protected group.
 
@@ -172,7 +166,6 @@ class Fairness:
                           If set to ``None``, it will use the biggest group as the reference.
         :param favorable_class: Positive/favorable outcome class of the response.
         :param figsize: Figure size; passed directly to Matplotlib
-        :param save_plot_path: A path to save the plot via using matplotlib function savefig.
 
         :return: Matplotlib Figure object
 
@@ -198,9 +191,6 @@ class Fairness:
         >>> gbm.fair_roc_plot(test, protected_columns, reference, favorable_class)
         """
         import h2o
-        from h2o.utils.shared_utils import can_use_numpy
-        if not can_use_numpy():
-            raise ImportError("numpy is required for fair_roc_plot.")
         from h2o.explanation._explain import NumpyFrame
         from h2o.plot import get_matplotlib_pyplot
         from h2o.utils.typechecks import assert_is_type
@@ -226,11 +216,9 @@ class Fairness:
         plt.xlabel("False Positive Rate")
         plt.ylabel("True Positive Rate")
         plt.title("Receiver Operating Characteristic Curve")
-        if save_plot_path is not None:
-            plt.savefig(fname=save_plot_path)
         return plt.gcf()
 
-    def fair_pr_plot(self, frame, protected_columns, reference, favorable_class, figsize=(16, 9), save_plot_path=None):
+    def fair_pr_plot(self, frame, protected_columns, reference, favorable_class, figsize=(16, 9)):
         """
         Plot PR curve per protected group.
         :param frame: H2OFrame
@@ -240,7 +228,6 @@ class Fairness:
                           If set to ``None``, it will use the biggest group as the reference.
         :param favorable_class: Positive/favorable outcome class of the response.
         :param figsize: Figure size; passed directly to Matplotlib
-        :param save_plot_path: A path to save the plot via using matplotlib function savefig.
 
         :return: Matplotlib Figure object
 
@@ -267,9 +254,7 @@ class Fairness:
         """
         import h2o
         from h2o.utils.typechecks import assert_is_type
-        from h2o.utils.shared_utils import can_use_numpy
-        if not can_use_numpy():
-            raise ImportError("numpy is required for fair_pr_plot.")
+
         from h2o.explanation._explain import NumpyFrame
         from h2o.plot import get_matplotlib_pyplot
 
@@ -299,12 +284,9 @@ class Fairness:
         plt.xlabel("Recall")
         plt.ylabel("Precision")
         plt.title("Precision-Recall Curve")
-        if save_plot_path is not None:
-            plt.savefig(fname=save_plot_path)
         return plt.gcf()
 
-    def fair_shap_plot(self, frame, column, protected_columns, autoscale=True, figsize=(16, 9), jitter=0.35, alpha=1,
-                       save_plot_path_prefix=None):
+    def fair_shap_plot(self, frame, column, protected_columns, autoscale=True, figsize=(16, 9), jitter=0.35, alpha=1):
         """
         SHAP summary plot for one feature with protected groups on y-axis.
 
@@ -317,11 +299,7 @@ class Fairness:
         :param figsize: Tuple with figure size; passed directly to matplotlib.
         :param jitter: Amount of jitter used to show the point density.
         :param alpha: Transparency of the points.
-        :param save_plot_path_prefix: A prefix of the path to save the plot via using matplotlib function savefig. 
-                                      The suffix of the path will be determined from a column name for which SHAP values
-                                      were calculated for.
-        
-        :return: H2OExplanation object
+        :return: Matplotlib Figure object
 
         :examples:
         >>> from h2o.estimators import H2OGradientBoostingEstimator
@@ -345,10 +323,6 @@ class Fairness:
         >>> gbm.fair_shap_plot(test, "AGE", protected_columns)
         """
         import h2o
-        from h2o.utils.shared_utils import can_use_numpy
-        if not can_use_numpy():
-            raise ImportError("numpy is required for fair_shap_plot.")
-        import numpy as np
         from h2o.explanation._explain import no_progress_block
         from h2o.explanation import H2OExplanation
         from h2o.explanation._explain import NumpyFrame
@@ -404,8 +378,6 @@ class Fairness:
             plt.yticks(range(len(result)), [", ".join(pg) for pg, _, _ in result])
             plt.grid()
             plt.colorbar().set_label("log({})".format(contr_column) if autoscale else contr_column)
-            if save_plot_path_prefix is not None:
-                plt.savefig(fname=save_plot_path_prefix + "_" +  contr_column)
             plots[contr_column] = plt.gcf()
         return plots
 
@@ -448,9 +420,6 @@ class Fairness:
         >>> gbm.inspect_model_fairness(test, protected_columns, reference, favorable_class)
         """
         import h2o
-        from h2o.utils.shared_utils import can_use_numpy
-        if not can_use_numpy():
-            raise ImportError("numpy is required for inspect_model_fairness.")
         from h2o.explanation import H2OExplanation
         from h2o.explanation import Description
         from h2o.explanation._explain import NumpyFrame
