@@ -15,6 +15,9 @@
 # limitations under the License.
 #
 
-from ai.h2o.sparkling.ml.algos import H2OKMeans, H2OAutoML, H2OGridSearch, H2OGLM, H2OGBM, H2OXGBoost, H2ODeepLearning, H2ODRF
+from ai.h2o.sparkling.ml.algos import H2OKMeans, H2OAutoML, H2OGridSearch, H2OGLM, H2OGBM, H2OXGBoost, H2ODeepLearning
+from ai.h2o.sparkling.ml.algos import H2ODRF, H2OGAM, H2OIsolationForest, H2OCoxPH, H2ORuleFit
+from ai.h2o.sparkling.ml.algos import H2OStackedEnsemble, H2OExtendedIsolationForest
 
-__all__ = ["H2OAutoML", "H2OGridSearch", "H2OGLM", "H2OGBM", "H2OXGBoost", "H2ODeepLearning", "H2OKMeans", "H2ODRF"]
+__all__ = ["H2OAutoML", "H2OGridSearch", "H2OGLM", "H2OGAM", "H2OGBM", "H2OXGBoost", "H2ODeepLearning", "H2OKMeans",
+           "H2ODRF", "H2OIsolationForest", "H2OCoxPH", "H2ORuleFit", "H2OStackedEnsemble", "H2OExtendedIsolationForest"]
